# Setup in Apptio
### On this page
  * [Procedure](https://help.sap.com/docs/leanix/ea/setup-in-apptio#procedure)
  * [Apptio Service User Setup](https://help.sap.com/docs/leanix/ea/setup-in-apptio#apptio-service-user-setup)
  * [Minimum Required Permissions](https://help.sap.com/docs/leanix/ea/setup-in-apptio#minimum-required-permissions)


Set up Apptio for SAP LeanIX integration to export data to Apptio. Configure an Apptio Service User and correct permissions.
